@@ -53,6 +53,8 @@ def project(longitude, latitude):
     :return: Coordinates `(x,y)` in the "Web Mercator" projection, normalised
       to be in the range [0,1].
     """
+    if longitude < -180 or longitude > 180 or latitude <= -90 or latitude >= 90:
+        raise ValueError(f"Longitude/Latitude ({longitude}/{latitude}) is out of valid range [-180,180] / [-90,90].  Did you swap them around?")
     xtile = (longitude + 180.0) / 360.0
     lat_rad = _math.radians(latitude)
     ytile = (1.0 - _math.log(_math.tan(lat_rad) + (1 / _math.cos(lat_rad))) / _math.pi) / 2.0
@@ -360,10 +362,9 @@ class Plotter():
     :param tile_provider: The :class:`tiles.Tiles` object which provides
       tiles.
     :param zoom: If not `None`, then use this zoom level (will be clipped to
-      the best zoom to tile provider can give).
+      the best zoom which the tile provider can give).
     :param width: Optional target width in pixels.
     :param height: Optional target height in pixels.
-    :param tile_size: The (square) tile size, defaults to 256 pixels.
     """
     def __init__(self, extent, tile_provider, zoom=None, width=None, height=None):
         if zoom is None and width is None and height is None:
@@ -453,11 +454,10 @@ class Plotter():
         ax.set(xlim = self.extent.xrange, ylim = self.extent.yrange)
 
     def as_one_image(self, allow_large = False):
-        """Use these settings to assemble tiles into a single image.
+        """Use these settings to assemble tiles into a single image.  Will always
+        return an image which is a whole number of tiles width and height; the
+        exact extent will be a sub-rectangle of the image.
 
-        :param ax: The axes object to plot to.
-        :param tile_provider: The :class:`tiles.Tiles` object which provides
-          tiles.
         :param allow_large: If False (default) then don't use more than 128
           tiles.  A guard against spamming the tile server.tile_provider
           
@@ -501,21 +501,32 @@ class Plotter():
 _NATIVE_LONLAT = 4326
 _WEB_MERCATOR = 3857
 
+def _read_crs(crs):
+    try:
+        return crs["init"]
+    except:
+        pass
+    try:
+        return crs.srs
+    except:
+        pass
+    return None
+
 def _parse_crs(crs):
     if crs is None:
         return _NATIVE_LONLAT
-    try:
-        parts = crs["init"].split(":")
-        if parts[0].upper() != "EPSG":
-            raise ValueError("Unknown projection '{}'".format(crs["init"]))
-        code = int(parts[1])
-        if code == _NATIVE_LONLAT:
-            return _NATIVE_LONLAT
-        if code == 3857 or code == 3785:
-            return _WEB_MERCATOR
-        raise ValueError("Unsupported projection '{}'".format(crs["init"]))
-    except Exception:
+    crs = _read_crs(crs)
+    if crs is None:    
         raise ValueError("Unknown crs data: '{}'".format(crs))
+    parts = crs.split(":")
+    if parts[0].upper() != "EPSG":
+        raise ValueError("Unknown projection '{}'".format(crs))
+    code = int(parts[1])
+    if code == _NATIVE_LONLAT:
+        return _NATIVE_LONLAT
+    if code == 3857 or code == 3785:
+        return _WEB_MERCATOR
+    raise ValueError("Unsupported projection '{}'".format(crs))
 
 def extent_from_frame(frame, buffer=0):
     """Minimal interface to compute an :class:`Extent` from a geoPandas
@@ -584,22 +595,23 @@ def points_from_frame(frame):
 try:
     import pyproj as _pyproj
 except:
-    import logging
-    logging.getLogger(__name__).error("Failed to load module 'pyproj'.")
     _pyproj = None
 
 if _pyproj is not None:
-    _proj3857 = _pyproj.Proj({"init":"EPSG:3857"})
-    _proj3785 = _pyproj.Proj({"init":"EPSG:3785"})
+    _proj3857 = _pyproj.CRS("EPSG:3857")
+    _proj3785 = _pyproj.CRS("EPSG:3785")
+    _proj4326 = _pyproj.CRS("epsg:4326")
+    _proj_to_3857 = _pyproj.Transformer.from_crs(_proj4326, _proj3857).transform
+    _proj_to_3785 = _pyproj.Transformer.from_crs(_proj4326, _proj3785).transform
 
 def project_3785(longitude, latitude):
     """Project using :module:`pyproj` and EPSG:3785."""
-    global _proj3785
-    xx, yy = _proj3785(longitude, latitude)
+    global _proj_to_3857
+    xx, yy = _proj_to_3857(latitude, longitude)
     return _from_3857(xx, yy)
 
 def project_3857(longitude, latitude):
     """Project using :module:`pyproj` and EPSG:3857."""
-    global _proj3857
-    xx, yy = _proj3857(longitude, latitude)
+    global _proj_to_3785
+    xx, yy = _proj_to_3785(latitude, longitude)
     return _from_3857(xx, yy)
